==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetypes/rev20160320/yrtietftetypes/tunnelpathsrlgs/tunnelpathsrlgs/style/named/constraints/DefaultConstraint.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.tunnelpathsrlgs.tunnelpathsrlgs.style.named.constraints;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.tunnelpathsrlgs.tunnelpathsrlgs.style.named.constraints.constraint.SrlgNames;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of constraint.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultConstraint extends InnerModelObject implements Constraint {
    protected List<SrlgNames> srlgNames;

    @Override
    public List<SrlgNames> srlgNames() {
        return srlgNames;
    }

    @Override
    public void srlgNames(List<SrlgNames> srlgNames) {
        this.srlgNames = srlgNames;
    }

    @Override
    public void addToSrlgNames(SrlgNames addTo) {
        if (srlgNames == null) {
            srlgNames = new ArrayList<>();
        }
        srlgNames.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(srlgNames);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultConstraint) {
            DefaultConstraint other = (DefaultConstraint) obj;
            return
                Objects.equals(srlgNames, other.srlgNames);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("srlgNames=" + srlgNames)
            .toString();
    }


    /**
     * Creates an instance of defaultConstraint.
     */
    public DefaultConstraint() {
    }

}

==> onos-yang-runtime-2.4-sources.jar: org/onosproject/yang/gen/v1/yrtietftetypes/rev20160320/yrtietftetypes/tunnelpathsrlgs/tunnelpathsrlgs/style/named/constraints/DefaultConstraint.java <==
/*
 * Copyright 2018-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.tunnelpathsrlgs.tunnelpathsrlgs.style.named.constraints;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.tunnelpathsrlgs.tunnelpathsrlgs.style.named.constraints.constraint.SrlgNames;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of constraint.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultConstraint extends InnerModelObject implements Constraint {
    protected List<SrlgNames> srlgNames;

    @Override
    public List<SrlgNames> srlgNames() {
        return srlgNames;
    }

    @Override
    public void srlgNames(List<SrlgNames> srlgNames) {
        this.srlgNames = srlgNames;
    }

    @Override
    public void addToSrlgNames(SrlgNames addTo) {
        if (srlgNames == null) {
            srlgNames = new ArrayList<>();
        }
        srlgNames.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(srlgNames);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultConstraint) {
            DefaultConstraint other = (DefaultConstraint) obj;
            return
                Objects.deepEquals(srlgNames, other.srlgNames);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("srlgNames=" + srlgNames)
            .toString();
    }


    /**
     * Creates an instance of defaultConstraint.
     */
    public DefaultConstraint() {
    }

}
